==> social_signals-0.0.1.tar.gz: social_signals-0.0.1/README.md <==
# social_signals

**Channel the power of data for societal good with social_signals: the definitive Python toolkit for ethically sourcing and interpreting the social pulse of the digital world.**

## About `social_signals`

In a data-driven world, the `social_signals` toolkit is an indispensable ally for developers and researchers who need to harvest public data efficiently and ethically. Built with the modern data product builder in mind, it serves as a pragmatic, yet principled, gateway to understanding societal trends, opinions, and movements. `social_signals` delivers the power to tap into a wealth of social signal feeds while ensuring compliance with the highest standards of data ethics and privacy.

## Features

- **Extensible Data Connectors:** Effortlessly connect to a variety of data sources with built-in support for APIs, databases, and creative data retrieval methods.
- **Ethical Data Harvesting:** Compliant with legal frameworks, we ensure the data is sourced responsibly and ethically.
- **User-Centric Design:** Built for Python-savvy data product builders, focusing on efficiency and performance.

## Installation

To install the package, use Poetry:

```bash
poetry add social_signals
```

## Quick Start

```python
from social_signals import gdelt

# Harvest GDELT articles within a date range and specific criteria
articles_df = gdelt.get_articles(from_date, to_date, event_code, country)
```

## Documentation
Dive deeper into the usage and capabilities of social_signals in our [documentation](/docs/index.md).

## Examples
Explore practical examples and use cases in the [examples](/examples/index.md) section.

## Contributing
Interested in contributing to the social_signals project? Check out our [contribution guidelines](/CONTRIBUTING.md).

## License
social_signals is released under the [MIT License](LICENSE).

## Join the Movement
social_signals is more than a package; it's a statement. By using it, you join a community dedicated to fostering transparency, progress, and data-driven social innovation. Let's craft a better society together, one data point at a time.

==> social_signals-0.0.2.tar.gz: social_signals-0.0.2/README.md <==
# social_signals

**Channel the power of data for societal good with social_signals: the definitive Python toolkit for ethically sourcing and interpreting the social pulse of the digital world.**

## About `social_signals`

In a data-driven world, the `social_signals` toolkit is an indispensable ally for developers and researchers who need to harvest public data efficiently and ethically. Built with the modern data product builder in mind, it serves as a pragmatic, yet principled, gateway to understanding societal trends, opinions, and movements. `social_signals` delivers the power to tap into a wealth of social signal feeds while ensuring compliance with the highest standards of data ethics and privacy.

## Features

- **Extensible Data Connectors:** Effortlessly connect to a variety of data sources with built-in support for APIs, databases, and creative data retrieval methods.
- **Ethical Data Harvesting:** Compliant with legal frameworks, we ensure the data is sourced responsibly and ethically.
- **User-Centric Design:** Built for Python-savvy data product builders, focusing on efficiency and performance.

## Installation

To install the package:

```bash
pip install social-signals
```

## Quick Start

```python
from social_signals.gdelt.api import get_gkg_articles

# Harvest GDELT articles within a date range and specific criteria
articles_df = gdelt_articles_df = get_gkg_articles(..)
```

## Examples
Explore practical examples and use cases in the [examples](/examples/index.md) section.

## Contributing
Interested in contributing to the social_signals project? Check out our [contribution guidelines](/CONTRIBUTING.md).

## License
social_signals is released under the [MIT License](LICENSE).
